
.. _library-api:

=========================
Library API Documentation
=========================
The page contains the low-level documentation for each of the importable
modules in ``dbilib``.

In addition to the documentation, most of the public methods come with one
or more usage examples and access to the source code itself.

.. toctree:: 
   :caption: Links to module-level documentation
   :maxdepth: 1

   database
   _dbi_base
   _dbi_mssql
   _dbi_mysql
   _dbi_oracle
   _dbi_sqlite

